#
# Conditional build:
%bcond_with	system_smesh	# use system version of Salome's Mesh
%bcond_with	system_zipios	# use system version of zipios++

Summary:	A general purpose 3D CAD modeler
Name:		FreeCAD
Version:	1.0.0
Release:	4
License:	LGPL v2
Group:		Applications/Engineering
Source0:	https://github.com/FreeCAD/FreeCAD/releases/download/%{version}/freecad_source.tar.gz
# Source0-md5:	6f0d75711b1d3b3ba35cb4e79c200c2d
Patch0:		apphome.patch
URL:		http://freecadweb.org/
# Utilities
BuildRequires:	cmake
BuildRequires:	desktop-file-utils
BuildRequires:	dos2unix
BuildRequires:	doxygen
BuildRequires:	gcc-fortran
BuildRequires:	gettext
BuildRequires:	graphviz
%{?with_system_smesh:BuildRequires:  smesh-devel}
BuildRequires:	swig
BuildRequires:	tbb-devel
# Development Libraries
BuildRequires:	Coin-devel
BuildRequires:	FreeImage-devel
BuildRequires:	Mesa-libGLU-devel
BuildRequires:	OpenCASCADE-devel
BuildRequires:	PyCXX
BuildRequires:	Qt6Concurrent-devel
BuildRequires:	Qt6Core-devel
BuildRequires:	Qt6Designer-devel
BuildRequires:	Qt6Network-devel
BuildRequires:	Qt6OpenGL-devel
BuildRequires:	Qt6PrintSupport-devel
BuildRequires:	Qt6Svg-devel
BuildRequires:	Qt6Test-devel
BuildRequires:	Qt6UiTools-devel
BuildRequires:	Qt6WebEngine-devel
BuildRequires:	Qt6Widgets-devel
BuildRequires:	Qt6Xml-devel
BuildRequires:	SoQt-devel
BuildRequires:	appstream-glib-devel
BuildRequires:	boost-devel >= 1:1.85.0
BuildRequires:	eigen3
BuildRequires:	ffmpeg-devel >= 6.0
BuildRequires:	hdf5-c++-devel
BuildRequires:	libicu-devel
BuildRequires:	libspnav-devel
BuildRequires:	med-devel
BuildRequires:	netcdf-cxx4-devel
BuildRequires:	netgen-mesher-devel
# not needed at the moment
#BuildRequires:  opencv-devel
BuildRequires:	python3-PySide6
BuildRequires:	python3-devel
BuildRequires:	python3-matplotlib
BuildRequires:	python3-pivy
BuildRequires:	python3-pivy-gui
BuildRequires:	shiboken6
BuildRequires:	vtk-devel
BuildRequires:	xerces-c
BuildRequires:	xerces-c-devel
BuildRequires:	xorg-lib-libXmu-devel
%{?with_system_zipios:BuildRequires:	zipios++-devel}
Requires:	%{name}-data = %{version}-%{release}
Requires:	glib2 >= 1:2.26.0
# Needed for plugin support and is not a soname dependency.
Requires:	hicolor-icon-theme
Requires:	python3-PySide6
Requires:	python3-matplotlib
Requires:	python3-pivy
Requires:	python3-pivy-gui
ExcludeArch:	%{ix86} x32
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
FreeCAD is a general purpose Open Source 3D CAD/MCAD/CAx/CAE/PLM
modeler, aimed directly at mechanical engineering and product design
but also fits a wider range of uses in engineering, such as
architecture or other engineering specialties. It is a feature-based
parametric modeler with a modular software architecture which makes it
easy to provide additional functionality without modifying the core
system.

%package data
Summary:	Data files for FreeCAD
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description data
Data files for FreeCAD.

%prep
%setup -q -c
%patch -P 0 -p1

%build
#	-DFREECAD_USE_EXTERNAL_PIVY=TRUE \
install -d build
cd build
%cmake ../ \
	-DCMAKE_INSTALL_PREFIX=%{_libdir}/%{name} \
	-DCMAKE_INSTALL_DATADIR=%{_datadir}/%{name} \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
	-DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
	-DCMAKE_INSTALL_LIBDIR=%{_libdir}/%{name}/lib \
	-DAPPHOMEPATH=%{_libdir}/%{name} \
	-DLIBRARYDIR=%{_libdir}/%{name}/lib \
	-DRESOURCEDIR=%{_datadir}/%{name} \
	-DENABLE_DEVELOPER_TESTS=OFF \
	-DBUILD_DESIGNER_PLUGIN=ON \
	-DBUILD_FEM_NETGEN=ON \
	-DFREECAD_QT_MAJOR_VERSION=6 \
	-DQT_DEFAULT_MAJOR_VERSION=6 \
%if %{with system_smesh}
	-DFREECAD_USE_EXTERNAL_SMESH=ON \
	-DSMESH_INCLUDE_DIR=%{_includedir}/smesh \
%endif
	%{cmake_on_off system_zipios FREECAD_USE_EXTERNAL_ZIPIOS}

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%py3_ocomp $RPM_BUILD_ROOT{py3_sitescriptdir}

%{__rm} -r $RPM_BUILD_ROOT{%{_includedir},%{_npkgconfigdir}}
%{__rm} -r $RPM_BUILD_ROOT%{_libdir}/FreeCAD/include
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/FreeCAD

%post
%update_icon_cache hicolor
%update_desktop_database
%update_mime_database

%postun
if [ $1 -eq 0 ] ; then
	%update_icon_cache hicolor
fi
%update_desktop_database
%update_mime_database

%posttrans
%update_icon_cache hicolor

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md SECURITY.md
%doc build/usr/share/doc/FreeCAD/LICENSE.html
%doc build/usr/share/doc/FreeCAD/ThirdPartyLibraries.html
%attr(755,root,root) %{_bindir}/FreeCAD
%attr(755,root,root) %{_bindir}/FreeCADCmd
%{_datadir}/metainfo/*.xml
%{_desktopdir}/*.desktop
%{_iconsdir}/hicolor/*x*/apps/org.freecad.FreeCAD.png
%{_iconsdir}/hicolor/scalable/apps/org.freecad.FreeCAD.svg
%{_iconsdir}/hicolor/scalable/mimetypes/application-x-extension-fcstd.svg
%{_pixmapsdir}/freecad.xpm
%{_datadir}/mime/packages/*.xml
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/Ext
%{_libdir}/%{name}/Mod
%dir %{_libdir}/%{name}/lib
%attr(755,root,root) %{_libdir}/%{name}/lib/*.so
%attr(755,root,root) %{_libdir}/%{name}/lib/libOndselSolver.so.*
%{py3_sitescriptdir}/freecad
%{_datadir}/thumbnailers/FreeCAD.thumbnailer

%files data
%defattr(644,root,root,755)
%{_datadir}/%{name}
%changelog
* Mon Mar 24 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/FreeCAD.git;a=log;h=master

* Mon Mar 24 2025 Jan Rękorajski <baggins@pld-linux.org> 0872d68
- Release 4 (by relup.sh)

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> b63b98e
- Release 3 (by relup.sh)

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> 4b5ed26
- python 3.13 rebuild

* Mon Dec 30 2024 Jan Rękorajski <baggins@pld-linux.org> 138722b
- rel 1

* Mon Dec 30 2024 Jan Rękorajski <baggins@pld-linux.org> 9f23e32
- no netgen and Qt6WebEngine in ix86 and x32

* Mon Dec 30 2024 Jan Rękorajski <baggins@pld-linux.org> 384aaba
- updated deps and files

* Sun Dec 29 2024 Jan Rękorajski <baggins@pld-linux.org> 5058d8e
- switch to Qt6 for PySide and shiboken

* Sat Dec 28 2024 Jan Rękorajski <baggins@pld-linux.org> d7290c6
- updated BR, build and files
- set app home dir to somethin sensible so it can find Mod/Ext/etc. dirs

* Sun Dec 15 2024 Jan Rękorajski <baggins@pld-linux.org> 0238d39
- fix includedir removal

* Sun Dec 15 2024 Jan Rękorajski <baggins@pld-linux.org> d730b1e
- drop plugin detection shenanigans
- updated files

* Sat Dec 14 2024 Jan Rękorajski <baggins@pld-linux.org> 159539d
- builds only with internal zipios++ for now
- removed obsolete files

* Fri Dec 13 2024 Jan Rękorajski <baggins@pld-linux.org> 3d2271c
- updated BRs, does not seem to build with OCE anymore

* Fri Nov 29 2024 Jan Rękorajski <baggins@pld-linux.org> b75ea38
- small deps cleanup

* Fri Nov 29 2024 Jan Rękorajski <baggins@pld-linux.org> 2e91313
- started update to 1.0.0

* Fri Nov 29 2024 Jan Rękorajski <baggins@pld-linux.org> 792987d
- renamed to FreeCAD to match upstream

* Fri Jun 12 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> a99710a
- save work

* Fri Jun 12 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 152a295
- we have update_icon_cache macro

* Fri Jun 12 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 600faea
- builds (--nodeps due to netgen-mesher not yet available in pld)

* Thu Jun 11 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> c177ecb
- more work

* Thu Jun 11 2015 Elan Ruusamäe <glen@delfi.ee> 98386db
- adapter

